package jalview.ws.rest.params;

import jalview.ws.rest.InputType;
import jalview.ws.rest.NoValidInputDataException;
import jalview.ws.rest.RestJob;

import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.List;

import org.apache.http.entity.mime.content.ContentBody;
import org.apache.http.entity.mime.content.StringBody;

/**
 * defines a constant value always provided as a parameter.
 * @author JimP
 *
 */
public class JobConstant extends InputType
{

  String value;
  /**
   * 
   * @param param name of parameter
   * @param val value of parameter
   */
  public JobConstant(String param, String val)
  {
    // needs no data from the restJob
    super(null);
    this.token = param;
    value = val;
  }

  @Override
  public ContentBody formatForInput(RestJob rj)
          throws UnsupportedEncodingException, NoValidInputDataException
  {
    
    return new StringBody(value);
  }

  @Override
  public List<String> getURLEncodedParameter()
  {
    ArrayList<String> prm = new ArrayList<String>();
    
    if (value!=null && value.length()>0)
    {
      prm.add(value);
    }
    return prm;
  }

  @Override
  public String getURLtokenPrefix()
  {
    return "";
  }

  @Override
  public boolean configureFromURLtokenString(List<String> tokenstring,
          StringBuffer warnings)
  {
    if (tokenstring.size()>1) {
      warnings.append("IMPLEMENTATION ERROR: Constant POST parameters cannot have more than one value.");
      return false;
    }
    if (tokenstring.size()==1) {
      value = tokenstring.get(0);
    }
    return true;
  }

  @Override
  public boolean configureProperty(String tok, String val,
          StringBuffer warnings)
  {
    warnings.append("IMPLEMENTATION ERROR: No Properties to configure for a Constant parameter.");
    return false;
  }
}
